rss_feed

# ElCato Static Blogging Platform

home Home
pages elcato
pages blog
pages orgmode

## Introduction

El Cato is a static blog generator using org markdown files, you can see a demo on gitlab which gets generated from the org files in this project.

## Getting started

### Creating a brand new Blog

First of initialize your blog with the command below adjust the path parameter to suit you.

    1
    elcato init --path=/tmp/myblog

### Adding a new post

If you are inside your project root you can omit the path parameter as it will use the one from your yaml config.

    1
    elcato create --path=/tmp/myblog

### Modifying the defaults

Edit the elcato.yaml file and modify the defaults to suit you in particular the Author and Blog blocks.

### Configuration

You can configure the static values using a yaml file this gets created when you Initialize your blog. Common settings are your personal details and your blog details like name and url.

## Advanced usage

### Change code styles

If you want to change the colours used in code highlighting generate a new stylesheet like below.

    1
    pygmentize -S monokai -f html -a .highlight -a .code  > output/default.css

### Org Tips

Limit display size of all images in org buffers set this at the top of your page.

> #+ATTR_ORG: :width 400